# shore
Python wapper for OCEAN(FEFF) code.
Calculates XAS.


### The structure of the code:
<img src="img/img2.png" alt="drawing" width="700"/>

### The input object structure:
<img src="img/img3.png" alt="drawing" width="700"/>